import { BaseOpenAISDKHandler } from './shared/baseOpenAI';
import { LLMProvider } from '../constants/llmProvider';
import { ToolResponse } from '../models/toolResponse';
/**
 * Class representing the LangChain LLM provider.
 */
export declare class LangChain extends BaseOpenAISDKHandler {
    /**
     * Determines if this provider should handle the specified LLM provider.
     * @param llmProvider - The LLM provider to check.
     * @returns True if the provider should handle the specified LLM provider, otherwise false.
     */
    static shouldHandle(llmProvider: LLMProvider): boolean;
    /**
     * Invokes the tools based on the tool selector response.
     * @param toolSelectorResponse - The response from the tool selector.
     * @returns An array of tool responses.
     * @throws Will throw an error if the tool selector response does not contain valid choices.
     */
    invokeTools(toolSelectorResponse: any): ToolResponse[];
}
