import { BaseOpenAISDKHandler } from './shared/baseOpenAI';
import { LLMProvider } from '../constants/llmProvider';
/**
 * @class OpenAISupportedModels
 * @description A class containing constants representing various supported models in OpenAI.
 */
export declare abstract class OpenAISupportedModels {
    /**
     * @constant
     * @type {string}
     * @description OpenAI GPT-4 model.
     */
    static readonly GPT_4: string;
    /**
     * @constant
     * @type {string}
     * @description OpenAI GPT-4o model.
     */
    static readonly GPT_4_O: string;
    /**
     * @constant
     * @type {string}
     * @description OpenAI GPT-4o Mini model.
     */
    static readonly GPT_4_O_MINI: string;
}
/**
 * Class representing the OpenAI LLM provider.
 */
export declare class OpenAI extends BaseOpenAISDKHandler {
    /**
     * Determines if this provider should handle the specified LLM provider.
     * @param llmProvider - The LLM provider to check.
     * @returns True if the provider should handle the specified LLM provider, otherwise false.
     */
    static shouldHandle(llmProvider: LLMProvider): boolean;
}
